import request from '@/utils/request'

/**
 * 企业安全所属分类、检查内容管理
 */

/**
 * 查询服务: 企业安全所属分类、检查内容 enterpriseSafetyInspectionContent:list
 * params: {
 *  level: 层级1: 所属分类  2: 检查内容
 *  page:  页码(0...N)
 *  pid
 *  size  每页显示的数目
 *  sort  以下列格式排序标准: property[,asc | desc]。默认排序顺序为升序。支持多种排序条件: 如: id,asc
 * }
 */

export function getEnterpriseSafetyInspectionContent(params) {
  return request({
    url: 'api/enterpriseSafetyInspectionContent',
    method: 'get',
    params
  })
}

/**
 * id
 * level  层级 1: 所属分类  2:检查内容
 * name   string 类别 /所属分类/检查内容
 * pid    integer($int32)
 * type   string  类别[安全资料类|现场检查类] 
 */

export function postEnterpriseSafetyInspectionContent(data) {
  return request({
    url: 'api/enterpriseSafetyInspectionContent',
    method: 'post',
    data
  })
}

/**
 * id
 * level  层级 1: 所属分类  2:检查内容
 * name   string 类别 /所属分类/检查内容
 * pid    integer($int32)
 * type   string  类别[安全资料类|现场检查类] 
 */
export function putEnterpriseSafetyInspectionContent(data) {
  return request({
    url: 'api/enterpriseSafetyInspectionContent',
    method: 'put',
    data
  })
}

/**
 * [
 *  {
 *    id: 0,
 *    level: 0
 *  }
 * ]
 */
export function deleteEnterpriseSafetyInspectionContent(data) {
  return request({
    url: 'api/enterpriseSafetyInspectionContent',
    method: 'delete',
    data
  })
}

/**
 * 企业安全发现问题管理
 */

/**
 * inspectionContentId
 * page
 * size
 * sort
 * 
 * enterpriseSafetyMatter:list
 */
export function getEnterpriseSafetyMatter(params) {
  return request({
    url: 'api/enterpriseSafetyMatter',
    method: 'get',
    params
  })
}

/**
 * basis     检查依据
 * id        id
 * inspectionContentId  检查内容id
 * name       问题名称
 * suggestion 整改建议
 */
export function postEnterpriseSafetyMatter(data) {
  return request({
    url: 'api/enterpriseSafetyMatter',
    method: 'post',
    data
  })
}

/**
 * basis   检查依据
 * id     id
 * inspectionContentId 检查内容
 * name   问题名称
 * suggestion   整改建议
 */
export function putEnterpriseSafetyMatter(data) {
  return request({
    url: 'api/enterpriseSafetyMatter',
    method: 'put',
    data
  })
}

/**
 * []
 */
export function deleteEnterpriseSafetyMatter(data) {
  return request({
    url: 'api/enterpriseSafetyMatter',
    method: 'delete',
    data
  })
}

/**
 * 查询企业安全信息
 */
export function findMattsByEnterpriseId(enterpriseId) {
  return request({
    url: 'api/enterpriseSafetyMatter/findByEnterpriseId',
    method: 'get',
    params: {
      enterpriseId
    }
  })
}

/**
 * 预览企业安全管理模板
 */

export function previewTemplate() {
  return request({
    url: 'api/enterpriseSafetyMatter/previewTemplate',
    method: 'get'
  })
}

/**
 * 企业安全管理评星
 */
export function enterSafetyMatterStar(enterpriseId) {
  return request({
    url: 'api/enterpriseSafetyMatter/star',
    method: 'get',
    params: {
      enterpriseId
    }
  })
}

/**
 * 获取所有待审核隐患
 */
export function getAllDangerToVerify(params) {
  return request({
    url: 'api/hiddenDangerToVerify',
    method: 'get',
    params
  })
}

/**
 * 待审核隐患修改
 */
export function verifyDanger(params) {
  return request({
    url: 'api/hiddenDangerToVerify/verify',
    method: 'get',
    params
  })
}

/**
 * 上传不符合
 * enterpriseId
 * matterId
 */
export function postUnSatify(enterpriseId, matterId) {
  return request({
    url: 'api/enterpriseSafetyInconformity',
    method: 'post',
    data: {
      enterpriseId,
      matterId
    }
  })
}
/**
 * 上传符合
 * enterpriseId
 * matterId
 */
export function deleteSatify(enterpriseId, matterId) {
  return request({
    url: 'api/enterpriseSafetyInconformity',
    method: 'delete',
    data: [{
      enterpriseId,
      matterId
    }]
  })
}